@@ -23,7 +23,7 @@
 #'   If given the method will return all objects accessible through this prefix.
 #' @family DBIConnection generics
 #' @export
-#' @examples
+#' @examplesIf requireNamespace("RSQLite", quietly = TRUE)
 #' con <- dbConnect(RSQLite::SQLite(), ":memory:")
 #'
 #' dbListObjects(con)
@@ -31,7 +31,8 @@
 #' dbListObjects(con)
 #'
 #' dbDisconnect(con)
-setGeneric("dbListObjects",
+setGeneric(
+  "dbListObjects",
   def = function(conn, prefix = NULL, ...) standardGeneric("dbListObjects"),
   valueClass = "data.frame"
 )
