@@ -21,13 +21,13 @@
 #' @templateVar method_name sqlData
 #'
 #' @export
-#' @examples
+#' @examplesIf requireNamespace("RSQLite", quietly = TRUE)
 #' con <- dbConnect(RSQLite::SQLite(), ":memory:")
 #'
 #' sqlData(con, head(iris))
 #' sqlData(con, head(mtcars))
 #'
 #' dbDisconnect(con)
-setGeneric("sqlData",
-  def = function(con, value, row.names = NA, ...) standardGeneric("sqlData")
-)
+setGeneric("sqlData", def = function(con, value, row.names = NA, ...) {
+  standardGeneric("sqlData")
+})
